@@ -2,8 +2,8 @@
 /*
  * Mandos plugin runner - Run Mandos plugins
  *
- * Copyright © 2008-2015 Teddy Hogeborn
- * Copyright © 2008-2015 Björn Påhlsson
+ * Copyright © 2008-2016 Teddy Hogeborn
+ * Copyright © 2008-2016 Björn Påhlsson
  * 
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -37,8 +37,7 @@
 #include <sys/select.h>		/* fd_set, select(), FD_ZERO(),
 				   FD_SET(), FD_ISSET(), FD_CLR */
 #include <sys/wait.h>		/* wait(), waitpid(), WIFEXITED(),
-				   WEXITSTATUS(), WTERMSIG(),
-				   WCOREDUMP() */
+				   WEXITSTATUS(), WTERMSIG() */
 #include <sys/stat.h>		/* struct stat, fstat(), S_ISREG() */
 #include <iso646.h>		/* and, or, not */
 #include <dirent.h>		/* struct dirent, scandirat() */
@@ -701,8 +700,7 @@ int main(int argc, char *argv[]){
 	custom_argc += 1;
 	{
 	  char **new_argv = realloc(custom_argv, sizeof(char *)
-				    * ((unsigned int)
-				       custom_argc + 1));
+				    * ((size_t)custom_argc + 1));
 	  if(new_argv == NULL){
 	    error(0, errno, "realloc");
 	    exitstatus = EX_OSERR;
@@ -892,18 +890,8 @@ int main(int argc, char *argv[]){
     return 1;
   }
   
-#ifdef __GLIBC__
-#if __GLIBC_PREREQ(2, 15)
   int numplugins = scandirat(dir_fd, ".", &direntries, good_name,
 			     alphasort);
-#else  /* not __GLIBC_PREREQ(2, 15) */
-  int numplugins = scandir(plugindir != NULL ? plugindir : PDIR,
-			   &direntries, good_name, alphasort);
-#endif	/* not __GLIBC_PREREQ(2, 15) */
-#else	/* not __GLIBC__ */
-  int numplugins = scandir(plugindir != NULL ? plugindir : PDIR,
-			   &direntries, good_name, alphasort);
-#endif	/* not __GLIBC__ */
   if(numplugins == -1){
     error(0, errno, "Could not scan plugin dir");
     direntries = NULL;
@@ -1115,20 +1103,7 @@ int main(int argc, char *argv[]){
       goto fallback;
     }
     
-#if defined (__GNUC__) and defined (__GLIBC__)
-#if not __GLIBC_PREREQ(2, 16)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wsign-conversion"
-#endif
-#endif
-    FD_SET(new_plugin->fd, &rfds_all); /* Spurious warning from
-					  -Wconversion in GNU libc
-					  before 2.16 */
-#if defined (__GNUC__) and defined (__GLIBC__)
-#if not __GLIBC_PREREQ(2, 16)
-#pragma GCC diagnostic pop
-#endif
-#endif
+    FD_SET(new_plugin->fd, &rfds_all);
     
     if(maxfd < new_plugin->fd){
       maxfd = new_plugin->fd;
@@ -1183,27 +1158,11 @@ int main(int argc, char *argv[]){
 		      (intmax_t) (proc->pid),
 		      WTERMSIG(proc->status),
 		      strsignal(WTERMSIG(proc->status)));
-	    } else if(WCOREDUMP(proc->status)){
-	      fprintf(stderr, "Plugin %s [%" PRIdMAX "] dumped"
-		      " core\n", proc->name, (intmax_t) (proc->pid));
 	    }
 	  }
 	  
 	  /* Remove the plugin */
-#if defined (__GNUC__) and defined (__GLIBC__)
-#if not __GLIBC_PREREQ(2, 16)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wsign-conversion"
-#endif
-#endif
-	  FD_CLR(proc->fd, &rfds_all); /* Spurious warning from
-					  -Wconversion in GNU libc
-					  before 2.16 */
-#if defined (__GNUC__) and defined (__GLIBC__)
-#if not __GLIBC_PREREQ(2, 16)
-#pragma GCC diagnostic pop
-#endif
-#endif
+	  FD_CLR(proc->fd, &rfds_all);
 	  
 	  /* Block signal while modifying process_list */
 	  ret = (int)TEMP_FAILURE_RETRY(sigprocmask
@@ -1249,23 +1208,7 @@ int main(int argc, char *argv[]){
       }
       
       /* This process has not completed.  Does it have any output? */
-#if defined (__GNUC__) and defined (__GLIBC__)
-#if not __GLIBC_PREREQ(2, 16)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wsign-conversion"
-#endif
-#endif
-      if(proc->eof or not FD_ISSET(proc->fd, &rfds)){ /* Spurious
-							 warning from
-							 -Wconversion
-							 in GNU libc
-							 before
-							 2.16 */
-#if defined (__GNUC__) and defined (__GLIBC__)
-#if not __GLIBC_PREREQ(2, 16)
-#pragma GCC diagnostic pop
-#endif
-#endif
+      if(proc->eof or not FD_ISSET(proc->fd, &rfds)){
 	/* This process had nothing to say at this time */
 	proc = proc->next;
 	continue;
